{% if area %}
  {% include 'tickle/area_breadcrumb.html' with area=area.parent is_parent=True %}
  {% if is_parent %}
    <span class='tickle-breadcrumb-item'>
      <a href='{% url "tickle:area-detail" pk=area.pk %}'>{{ area.name }}</a>
    </span>
  {% else %}
    <span class='tickle-breadcrumb-item'>
      {{ area.name }}
    </span>
  {% endif %}
{% else %}
  <span class='tickle-breadcrumb-item'>
    <a href='{% url "tickle:area-list" %}'>All</a>
  </span>
{% endif %}
